@@ -19,9 +19,9 @@ from typing import Union
 from urllib.parse import urlparse
 
 import pandas as pd
+import smart_open
 from airflow.hooks.base import BaseHook
 from airflow.models import BaseOperator
-from smart_open import open
 
 from astro.constants import DEFAULT_CHUNK_SIZE
 from astro.sql.table import Table, TempTable, create_table_name
@@ -83,6 +83,9 @@ class AgnosticLoadFile(BaseOperator):
             )
         else:
             self.output_table.schema = self.output_table.schema or get_schema()
+        if not self.output_table.table_name:
+            self.output_table.table_name = create_table_name(context=context)
+
         move_dataframe_to_sql(
             output_table_name=self.output_table.table_name,
             conn_id=self.output_table.conn_id,
@@ -129,7 +132,7 @@ class AgnosticLoadFile(BaseOperator):
         }
         mode = {"parquet": "rb"}
         deserialiser_params = {"ndjson": {"lines": True}}
-        with open(
+        with smart_open.open(
             path, mode=mode.get(file_type, "r"), transport_params=transport_params
         ) as stream:
             return deserialiser[file_type](
