@@ -6,7 +6,11 @@ from sqlalchemy.sql.schema import Table as SqlaTable
 
 from astro.sql.operators.sql_decorator import SqlDecoratoratedOperator
 from astro.sql.table import Table
-from astro.utils.schema_util import get_table_name
+from astro.utils.schema_util import (
+    get_error_string_for_multiple_dbs,
+    get_table_name,
+    tables_from_same_db,
+)
 
 
 class OutlierCheck:
@@ -166,6 +170,8 @@ class ChecksHandler:
 
 
 class AgnosticStatsCheck(SqlDecoratoratedOperator):
+    template_fields = ("table",)
+
     def __init__(
         self,
         checks: List[OutlierCheck],
@@ -196,9 +202,17 @@ class AgnosticStatsCheck(SqlDecoratoratedOperator):
 
         task_id = main_table.table_name + "_" + "stats_check"
 
+        if not tables_from_same_db([main_table, compare_table]):
+            raise ValueError(
+                get_error_string_for_multiple_dbs([main_table, compare_table])
+            )
+
         def null_function():
             pass
 
+        def handler_func(results):
+            return results.fetchall()
+
         super().__init__(
             raw_sql=True,
             parameters={},
@@ -208,13 +222,13 @@ class AgnosticStatsCheck(SqlDecoratoratedOperator):
             warehouse=main_table.warehouse,
             task_id=task_id,
             op_args=(),
+            handler=handler_func,
             python_callable=null_function,
             **kwargs,
         )
 
     def execute(self, context: Dict):
         conn_type = BaseHook.get_connection(self.conn_id).conn_type  # type: ignore
-        self.handler = lambda curr: curr.fetchall()
         checkHandler = ChecksHandler(self.checks, conn_type)
         metadata = MetaData()
         self.sql = checkHandler.prepare_comparison_sql(
@@ -225,7 +239,6 @@ class AgnosticStatsCheck(SqlDecoratoratedOperator):
         )
 
         results = super().execute(context)
-        results = results.fetchall()
         failed_checks = checkHandler.evaluate_results(
             results, self.max_rows_returned, conn_type
         )
@@ -242,10 +255,9 @@ class AgnosticStatsCheck(SqlDecoratoratedOperator):
             failed_values = {}
             for check_query in failed_check_sql:
                 check, self.sql, self.parameters = check_query
-                results = super().execute(context)
-                failed_values[check] = results.fetchall()
+                failed_values[check] = super().execute(context)
 
-            raise ValueError("Stats Check Failed. {}".format(failed_values))
+            raise ValueError("Stats Check Failed. %s", failed_values)
 
 
 def stats_check(
