@@ -16,11 +16,16 @@ limitations under the License.
 import os
 from typing import Optional, Union
 
+from airflow.hooks.sqlite_hook import SqliteHook
 from pandas import DataFrame
 from pandas.io.sql import SQLDatabase
-from snowflake.connector import pandas_tools
 
-from astro.utils.dependencies import BigQueryHook, PostgresHook, SnowflakeHook
+from astro.utils.dependencies import (
+    BigQueryHook,
+    PostgresHook,
+    SnowflakeHook,
+    pandas_tools,
+)
 from astro.utils.schema_util import create_schema_query, schema_exists
 
 
@@ -35,28 +40,44 @@ def move_dataframe_to_sql(
     user,
     chunksize,
 ):
-    # Select database Hook based on `conn` type
-    hook: Union[PostgresHook, SnowflakeHook] = {  # type: ignore
-        "postgresql": PostgresHook(postgres_conn_id=conn_id, schema=database),
-        "postgres": PostgresHook(postgres_conn_id=conn_id, schema=database),
-        "snowflake": SnowflakeHook(
-            snowflake_conn_id=conn_id,
-            database=database,
-            schema=schema,
-            warehouse=warehouse,
-        ),
-        "bigquery": BigQueryHook(use_legacy_sql=False, gcp_conn_id=conn_id),
-    }.get(conn_type, None)
-    if not hook:
-        raise ValueError("conn id needs to either snowflake or postgres")
+    hook_kwargs = {
+        "postgresql": {"postgres_conn_id": conn_id, "schema": database},
+        "postgres": {"postgres_conn_id": conn_id, "schema": database},
+        "snowflake": {
+            "snowflake_conn_id": conn_id,
+            "database": database,
+            "schema": schema,
+            "warehouse": warehouse,
+        },
+        "bigquery": {"use_legacy_sql": False, "gcp_conn_id": conn_id},
+        "sqlite": {"sqlite_conn_id": conn_id},
+    }
+    try:
+        hook_class = {
+            "postgresql": PostgresHook,
+            "postgres": PostgresHook,
+            "snowflake": SnowflakeHook,
+            "bigquery": BigQueryHook,
+            "sqlite": SqliteHook,
+        }[conn_type]
+    except KeyError:
+        raise ValueError(
+            f"The conn_id {conn_id} is of unsupported type {conn_type}. Current supported types: {list(hook_class.keys())}"
+        )
+    else:
+        hook = hook_class(**hook_kwargs[conn_type])
+
     if database:
         hook.database = database
 
-    if not schema_exists(hook=hook, schema=schema, conn_type=conn_type):
+    if conn_type != "sqlite" and not schema_exists(
+        hook=hook, schema=schema, conn_type=conn_type
+    ):
         schema_query = create_schema_query(
             conn_type=conn_type, hook=hook, schema_id=schema, user=user
         )
         hook.run(schema_query)
+
     if conn_type == "snowflake":
 
         db = SQLDatabase(engine=hook.get_sqlalchemy_engine())
@@ -83,6 +104,15 @@ def move_dataframe_to_sql(
             chunksize=chunksize,
             project_id=hook.project_id,
         )
+    elif conn_type == "sqlite":
+        df.to_sql(
+            output_table_name,
+            con=hook.get_sqlalchemy_engine(),
+            if_exists="replace",
+            chunksize=chunksize,
+            method="multi",
+            index=False,
+        )
     else:
         df.to_sql(
             output_table_name,
