@@ -2,9 +2,9 @@ import os
 from typing import List
 
 from airflow.hooks.base import BaseHook
-from psycopg2 import sql
 
 from astro.sql.table import Table
+from astro.utils.dependencies import postgres_sql
 
 
 def schema_exists(hook, schema, conn_type):
@@ -13,13 +13,13 @@ def schema_exists(hook, schema, conn_type):
             "SELECT schema_name FROM information_schema.schemata;",
             handler=lambda x: [y[0] for y in x.fetchall()],
         )
-        return schema in created_schemas
+        return schema.upper() in [c.upper() for c in created_schemas]
     elif conn_type == "snowflake":
         created_schemas = [
             x["SCHEMA_NAME"]
             for x in hook.run("SELECT SCHEMA_NAME from information_schema.schemata;")
         ]
-        return schema in created_schemas
+        return schema.upper() in [c.upper() for c in created_schemas]
     return False
 
 
@@ -27,11 +27,16 @@ def create_schema_query(conn_type, hook, schema_id, user):
 
     if conn_type in ["postgresql", "postgres"]:
         return (
-            sql.SQL("CREATE SCHEMA IF NOT EXISTS {schema} AUTHORIZATION {user}")
-            .format(schema=sql.Identifier(schema_id), user=sql.Identifier(user))
+            postgres_sql.SQL(
+                "CREATE SCHEMA IF NOT EXISTS {schema} AUTHORIZATION {user}"
+            )
+            .format(
+                schema=postgres_sql.Identifier(schema_id),
+                user=postgres_sql.Identifier(user),
+            )
             .as_string(hook.get_conn())
         )
-    elif conn_type in ["snowflake", "google_cloud_platform", "bigquery"]:
+    elif conn_type in ["snowflake", "google_cloud_platform", "bigquery", "sqlite"]:
         return f"CREATE SCHEMA IF NOT EXISTS {schema_id}"
 
 
@@ -54,7 +59,8 @@ def tables_from_same_db(tables: List[Table]):
     """
     conn_ids = set()
     for table in tables:
-        conn_ids.add(table.conn_id)
+        if table.conn_id:
+            conn_ids.add(table.conn_id)
     return len(conn_ids) == 1
 
 
@@ -64,4 +70,4 @@ def get_error_string_for_multiple_dbs(tables: List[Table]):
     :param tables: list of table
     :return: String: error string
     """
-    return f'Tables should belong to same db {", ".join([table.table_name for table in tables])}'
+    return f'Tables should belong to same db {", ".join([f"{table.table_name}: {table.conn_id}" for table in tables])}'
